==> ejc-prjfinance-api-3.0.1-20210723.063139-22-sources.jar: com/ejianc/business/prjfinance/vo/ProjectDutyLetterCostlistVO.java <==
package com.ejianc.business.prjfinance.vo;

import java.math.BigDecimal;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * <p>
 * 项目目标责任书--费用清单
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
public class ProjectDutyLetterCostlistVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 费用名称
     */
    private Long costId;

    /**
     * 费用名称
     */
    private String costName;

    /**
     * 增加/扣除
     */
    private String addOrDelete;

    /**
     * 数值
     */
    private String formula;

    /**
     * 公式--实际值
     */
    private String formulaDescribe;

    /**
     * 金额
     */
    @TableField("amount")
    private BigDecimal amount;

    /**
     * 备注
     */
    private String remarks;
    
    /**
     * 主表id
     */
    private Long dutyLetterId;
    
	public String getCostName() {
		return costName;
	}

	public void setCostName(String costName) {
		this.costName = costName;
	}

    @ReferSerialTransfer(referCode = "support-defdoc")
	public Long getCostId() {
		return costId;
	}

    @ReferDeserialTransfer
	public void setCostId(Long costId) {
		this.costId = costId;
	}

	public String getAddOrDelete() {
		return addOrDelete;
	}

	public void setAddOrDelete(String addOrDelete) {
		this.addOrDelete = addOrDelete;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public String getFormulaDescribe() {
		return formulaDescribe;
	}

	public void setFormulaDescribe(String formulaDescribe) {
		this.formulaDescribe = formulaDescribe;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public Long getDutyLetterId() {
		return dutyLetterId;
	}

	public void setDutyLetterId(Long dutyLetterId) {
		this.dutyLetterId = dutyLetterId;
	}
	
}

==> ejc-prjfinance-api-3.0.1-20210731.084904-52-sources.jar: com/ejianc/business/prjfinance/vo/ProjectDutyLetterCostlistVO.java <==
package com.ejianc.business.prjfinance.vo;

import java.math.BigDecimal;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * <p>
 * 项目目标责任书--费用清单
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
public class ProjectDutyLetterCostlistVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 费用名称
     */
    private Long costId;

    /**
     * 费用名称
     */
    private String costName;

    /**
     * 扣除/返还
     */
    private String backOrDel;

    /**
     * 数值
     */
    private String formula;

    /**
     * 公式--实际值
     */
    private String formulaDescribe;

    /**
     * 金额
     */
    private BigDecimal amount;

    /**
     * 备注
     */
    private String remarks;
    
    /**
     * 主表id
     */
    private Long dutyLetterId;
    
	public String getCostName() {
		return costName;
	}

	public void setCostName(String costName) {
		this.costName = costName;
	}

//    @ReferSerialTransfer(referCode = "support-defdoc")
	public Long getCostId() {
		return costId;
	}

//    @ReferDeserialTransfer
	public void setCostId(Long costId) {
		this.costId = costId;
	}

	public String getBackOrDel() {
		return backOrDel;
	}

	public void setBackOrDel(String backOrDel) {
		this.backOrDel = backOrDel;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public String getFormulaDescribe() {
		return formulaDescribe;
	}

	public void setFormulaDescribe(String formulaDescribe) {
		this.formulaDescribe = formulaDescribe;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public Long getDutyLetterId() {
		return dutyLetterId;
	}

	public void setDutyLetterId(Long dutyLetterId) {
		this.dutyLetterId = dutyLetterId;
	}
	
}
